==> server-api-impl-22.2.0-rc.2-sources.jar: com/xebialabs/deployit/core/rest/json/SatelliteInfoJsonWriter.java <==
package com.xebialabs.deployit.core.rest.json;

import com.google.common.annotations.VisibleForTesting;
import com.xebialabs.deployit.engine.api.dto.SatelliteInfo;
import com.xebialabs.xltype.serialization.json.SatelliteInfoJsonConverter;
import org.springframework.stereotype.Component;

import javax.ws.rs.Consumes;
import javax.ws.rs.Produces;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.ext.MessageBodyWriter;
import javax.ws.rs.ext.Provider;
import java.io.IOException;
import java.io.OutputStream;
import java.lang.annotation.Annotation;
import java.lang.reflect.Type;

@Component
@Provider
@Consumes({MediaType.APPLICATION_JSON})
@Produces({MediaType.APPLICATION_JSON})
public class SatelliteInfoJsonWriter implements MessageBodyWriter<SatelliteInfo> {

    @Override
    public boolean isWriteable(Class<?> type, final Type genericType, final Annotation[] annotations, final MediaType mediaType) {
        return SatelliteInfo.class.isAssignableFrom(type);
    }

    @Override
    public long getSize(final SatelliteInfo satelliteInfo, final Class<?> type, final Type genericType, final Annotation[] annotations, final MediaType mediaType) {
        return -1L;
    }

    @Override
    public void writeTo(final SatelliteInfo satelliteInfo, final Class<?> type, final Type genericType, final Annotation[] annotations, final MediaType mediaType, final MultivaluedMap<String, Object> httpHeaders, final OutputStream entityStream) throws IOException, WebApplicationException {
        entityStream.write(toJson(satelliteInfo).getBytes());
    }

    @VisibleForTesting
    String toJson(final SatelliteInfo satelliteInfo) {
        return new SatelliteInfoJsonConverter().toJson(satelliteInfo);
    }
}

==> server-api-impl-25.1.8-107.931-sources.jar: com/xebialabs/deployit/core/rest/json/SatelliteInfoJsonWriter.java <==
package com.xebialabs.deployit.core.rest.json;

import com.google.common.annotations.VisibleForTesting;
import com.xebialabs.deployit.engine.api.dto.SatelliteInfo;
import com.xebialabs.xltype.serialization.json.SatelliteInfoJsonConverter;
import org.springframework.stereotype.Component;

import jakarta.ws.rs.Consumes;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.WebApplicationException;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.MultivaluedMap;
import jakarta.ws.rs.ext.MessageBodyWriter;
import jakarta.ws.rs.ext.Provider;
import java.io.IOException;
import java.io.OutputStream;
import java.lang.annotation.Annotation;
import java.lang.reflect.Type;

@Component
@Provider
@Consumes({MediaType.APPLICATION_JSON})
@Produces({MediaType.APPLICATION_JSON})
public class SatelliteInfoJsonWriter implements MessageBodyWriter<SatelliteInfo> {

    @Override
    public boolean isWriteable(Class<?> type, final Type genericType, final Annotation[] annotations, final MediaType mediaType) {
        return SatelliteInfo.class.isAssignableFrom(type);
    }

    @Override
    public long getSize(final SatelliteInfo satelliteInfo, final Class<?> type, final Type genericType, final Annotation[] annotations, final MediaType mediaType) {
        return -1L;
    }

    @Override
    public void writeTo(final SatelliteInfo satelliteInfo, final Class<?> type, final Type genericType, final Annotation[] annotations, final MediaType mediaType, final MultivaluedMap<String, Object> httpHeaders, final OutputStream entityStream) throws IOException, WebApplicationException {
        entityStream.write(toJson(satelliteInfo).getBytes());
    }

    @VisibleForTesting
    String toJson(final SatelliteInfo satelliteInfo) {
        return new SatelliteInfoJsonConverter().toJson(satelliteInfo);
    }
}
